==> openmsghard-1.0.1.tar.gz: openmsghard-1.0.1/dbcon.c <==
#include "dbcon.h"
#include "common.h"
#define MAX_PATH 2048


void connect_db(MYSQL *conn) {

mysql_init(conn);

mysql_real_connect(conn,MYSQL_HOST,conf.mysql_id,conf.mysql_pw,conf.mysql_db,0,(char*)NULL,0);

printf("Connect DB!\n");


}

int user_check(MYSQL *conn,char *username) {
	printf("start user_check()\n");
	MYSQL_RES *res;
	MYSQL_ROW row;
	char query_buf[512];
	memset(query_buf,0x0,sizeof(query_buf));

	snprintf(query_buf,512,"select user_id from msghard_user");
	printf("%s\n",query_buf);	
	if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
	}
	
	res=mysql_store_result(conn);

	while((row = mysql_fetch_row(res))) {
		printf("db : user_id : %s\n",row[0]);
		
		if(strcmp(row[0],username)==0) {
			/* ̵  return 1 */
			return 1;
		}
	}
	printf("free()\n");
	mysql_free_result(res);
	
	return 0;


}


void db_user_add(MYSQL *conn,char *username) {
	printf("start db_user_add\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

	snprintf(query_buf,512,"insert into msghard_user values(\'%s\',sysdate(),sysdate(),%ld,%ld,%d,0,0,NULL,0,sysdate(),0,0,0,0)",username,conf.default_size,conf.default_size,0);

	if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
		printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
		error_handling("mysql error");
	}



}
void db_update_last_time(MYSQL *conn,char *username) {
	printf("start db_update_last_time\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set last_date=sysdate() where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

}
void db_insert_file(MYSQL *conn,char *username) {
        printf("start db_insert_file\n");

        char query_buf[512];
	char initial[50];
	memset(initial,0x0,50);
        memset(query_buf,0x0,sizeof(query_buf));
        strncpy(initial,file_queue[0].filename,50-3);
        initial[41]='.';
        initial[42]='.';
        initial[43]='\0';

	printf("insert check1\n");
	printf("%s\n",username);
	printf("%s\n",file_queue[0].filename);
	printf("%s\n",initial);
	printf("%s\n",file_queue[0].path);

        snprintf(query_buf,512,"insert into msghard_file values(NULL,\'%s\',\'%s\',\'%s\',%ld,sysdate(),0,\'%s\',0)",username,file_queue[0].filename,initial,file_queue[0].filesize,file_queue[0].path);
	printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }
	printf("return db\n");
}


void db_insert_dir(MYSQL *conn,char *username,char *dirname,char *present_path) {
        printf("start db_insert_file\n");

        char query_buf[512];
        char initial[50];
        memset(initial,0x0,50);
        memset(query_buf,0x0,sizeof(query_buf));
        strncpy(initial,dirname,50-3);
        initial[41]='.';
        initial[42]='.';
        initial[43]='\0';

        printf("insert check1\n");
        printf("%s\n",username);
        printf("%s\n",file_queue[0].filename);
        printf("%s\n",initial);
        printf("%s\n",file_queue[0].path);

        snprintf(query_buf,512,"insert into msghard_file values(NULL,\'%s\',\'%s\',\'%s\',%ld,sysdate(),1,\'%s\',0)",username,dirname,initial,0,present_path);
        printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }
        printf("return db\n");
}

void db_delete_dir_file(MYSQL *conn,char *username,char *filename,char *present_path) {
        printf("start db_delete_file\n");

        char query_buf[MAX_PATH];
        memset(query_buf,0x0,MAX_PATH);

        snprintf(query_buf,MAX_PATH,"delete from msghard_file where user_id=\'%s\' and locate=\'%s\'",username,present_path);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

}


void db_select_conf(MYSQL *conn,char *username,char *reg_date,int *is_pub,int *order,char *pub_name,long *send_size,long *recv_size,int *send_count,int *recv_count,long *total_size,long *use_size,long *odd_size) {


        printf("start user_check()\n");
        MYSQL_RES *res;
        MYSQL_ROW row;
        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));
        printf("check\n");

        snprintf(query_buf,512,"select * from msghard_user where user_id=\'%s\'",user_id);
        printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

        res=mysql_store_result(conn);
	printf("check1\n");

        while((row = mysql_fetch_row(res))) {
		printf("user_id : %s\n",row[1]);	
		strncpy(reg_date,row[1],strlen(row[1]));
                *total_size = atol(row[3]);
                *odd_size = atol(row[4]);
                *use_size = atol(row[5]);
                *is_pub = atoi(row[6]);
                *order = atoi(row[7]);
		printf("check_check\n");
		printf("row[8] : %s\n",row[8]);	
		if(row[8]==NULL) {
                        printf("haha\n");
                        strcpy(pub_name,"");
                }
		else {	
                	printf("hoho\n");
			strncpy(pub_name,row[8],strlen(row[8]));
		}

		printf("%s\n",pub_name);
                *send_count = atoi(row[9]);
                *send_size = atol(row[10]);
                *recv_count = atoi(row[11]);
                *recv_size = atol(row[12]);

		printf("recv_size : %d\n",*recv_size);
        }
        printf("check2\n");

        mysql_free_result(res);

	printf("ended db_conf\n");

}
void db_update_pub_name(MYSQL *conn,char *username,char *pub_name) {
        printf("start db_update_pub_name\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set conf_pubnm=\'%s\' where user_id=\'%s\'",pub_name,username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

}

void db_update_conf_pub_1(MYSQL *conn,char *username) {
        printf("start db_update_setpub\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set conf_pub=1 where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

	memset(query_buf,0x0,512);
        snprintf(query_buf,512,"update msghard_user set conf_pub_date=sysdate() where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }


}
void db_update_conf_pub_0(MYSQL *conn,char *username) {
        printf("start db_update_setpub\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set conf_pub=0 where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

}



void db_select_get_publist(MYSQL *conn,char *username,pub_list *publist_head,int *publist_max_count) {

	pub_list *p=NULL;
        printf("start db_select_get_publist\n");
        MYSQL_RES *res;
        MYSQL_ROW row;
        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));
        printf("check\n");

        snprintf(query_buf,512,"select user_id,conf_pubnm from msghard_user where conf_pub=1 order by conf_pub_date desc");
        printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

        res=mysql_store_result(conn);
        printf("check1\n");
	p=publist_head;
        while((row = mysql_fetch_row(res))) {
		printf("while\n");
		pub_list *node = (pub_list*)malloc(sizeof(pub_list));

		memset(node,0x0,sizeof(pub_list));
				
                printf("user_id : %s , subject : %s\n",row[0],row[1]);
		memset(node->data.username,0x0,256);

		strncpy(node->data.username , row[0] , strlen(row[0]));
		node->data.count = *publist_max_count +1;
		if(row[1] == NULL) {
			strcpy(node->data.subject,"");
		}
		else {
			strncpy(node->data.subject,row[1],strlen(row[1]));
		}
		p->Next = node;
		(*publist_max_count)++;



		printf("publist_max_count : %d\n",*publist_max_count);
		p=p->Next;
		printf("check\n");
        }

        mysql_free_result(res);

        printf("ended db_get_publist\n");

}

==> openmsghard-1.0.2.tar.gz: openmsghard-1.0.2/dbcon.c <==
#include "dbcon.h"
#include "common.h"
#define MAX_PATH 2048


void connect_db(MYSQL *conn) {

mysql_init(conn);

mysql_real_connect(conn,MYSQL_HOST,conf.mysql_id,conf.mysql_pw,conf.mysql_db,0,(char*)NULL,0);

printf("Connect DB!\n");


}

int user_check(MYSQL *conn,char *username) {
	//printf("start user_check()\n");
	MYSQL_RES *res;
	MYSQL_ROW row;
	char query_buf[512];
	memset(query_buf,0x0,sizeof(query_buf));

	snprintf(query_buf,512,"select user_id from msghard_user");
	//printf("%s\n",query_buf);	
	if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
	}
	
	res=mysql_store_result(conn);

	while((row = mysql_fetch_row(res))) {
		//printf("db : user_id : %s\n",row[0]);
		
		if(strcmp(row[0],username)==0) {
			/* ̵  return 1 */
			return 1;
		}
	}
	//printf("free()\n");
	mysql_free_result(res);
	
	return 0;


}


void db_user_add(MYSQL *conn,char *username) {
	printf("start db_user_add\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

	snprintf(query_buf,512,"insert into msghard_user values(\'%s\',sysdate(),sysdate(),%ld,%ld,%d,0,0,NULL,0,sysdate(),0,0,0,0)",username,conf.default_size,conf.default_size,0);

	if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
		printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
		error_handling("mysql error");
	}



}
void db_update_last_time(MYSQL *conn,char *username) {
	//printf("start db_update_last_time\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set last_date=sysdate() where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

}
void db_insert_file(MYSQL *conn,char *username) {
        //printf("start db_insert_file\n");

        char query_buf[512];
	char initial[50];
	memset(initial,0x0,50);
        memset(query_buf,0x0,sizeof(query_buf));
        strncpy(initial,file_queue[0].filename,50-3);
        initial[41]='.';
        initial[42]='.';
        initial[43]='\0';

	//printf("insert check1\n");
	//printf("%s\n",username);
	//printf("%s\n",file_queue[0].filename);
	//printf("%s\n",initial);
	//printf("%s\n",file_queue[0].path);

        snprintf(query_buf,512,"insert into msghard_file values(NULL,\'%s\',\'%s\',\'%s\',%ld,sysdate(),0,\'%s\',0)",username,file_queue[0].filename,initial,file_queue[0].filesize,file_queue[0].path);
	//printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }
	//printf("return db\n");
}


void db_insert_dir(MYSQL *conn,char *username,char *dirname,char *present_path) {
        printf("start db_insert_file\n");

        char query_buf[512];
        char initial[50];
        memset(initial,0x0,50);
        memset(query_buf,0x0,sizeof(query_buf));
        strncpy(initial,dirname,50-3);
        initial[41]='.';
        initial[42]='.';
        initial[43]='\0';

        //printf("insert check1\n");
        //printf("%s\n",username);
        //printf("%s\n",file_queue[0].filename);
        //printf("%s\n",initial);
        //printf("%s\n",file_queue[0].path);

        snprintf(query_buf,512,"insert into msghard_file values(NULL,\'%s\',\'%s\',\'%s\',%ld,sysdate(),1,\'%s\',0)",username,dirname,initial,0,present_path);
        //printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }
        //printf("return db\n");
}

void db_delete_dir_file(MYSQL *conn,char *username,char *filename,char *present_path) {
        printf("start db_delete_file\n");

        char query_buf[MAX_PATH];
        memset(query_buf,0x0,MAX_PATH);

        snprintf(query_buf,MAX_PATH,"delete from msghard_file where user_id=\'%s\' and locate=\'%s\'",username,present_path);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

}


void db_select_conf(MYSQL *conn,char *username,char *reg_date,int *is_pub,int *order,char *pub_name,long *send_size,long *recv_size,int *send_count,int *recv_count,long *total_size,long *use_size,long *odd_size) {


        printf("start user_check()\n");
        MYSQL_RES *res;
        MYSQL_ROW row;
        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));
        printf("check\n");

        snprintf(query_buf,512,"select * from msghard_user where user_id=\'%s\'",user_id);
        //printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

        res=mysql_store_result(conn);
	//printf("check1\n");

        while((row = mysql_fetch_row(res))) {
		//printf("user_id : %s\n",row[1]);	
		strncpy(reg_date,row[1],strlen(row[1]));
                *total_size = atol(row[3]);
                *odd_size = atol(row[4]);
                *use_size = atol(row[5]);
                *is_pub = atoi(row[6]);
                *order = atoi(row[7]);
		//printf("check_check\n");
		//printf("row[8] : %s\n",row[8]);	
		if(row[8]==NULL) {
                        printf("haha\n");
                        strcpy(pub_name,"");
                }
		else {	
                	printf("hoho\n");
			strncpy(pub_name,row[8],strlen(row[8]));
		}

		//printf("%s\n",pub_name);
                *send_count = atoi(row[9]);
                *send_size = atol(row[10]);
                *recv_count = atoi(row[11]);
                *recv_size = atol(row[12]);

		//printf("recv_size : %d\n",*recv_size);
        }
        //printf("check2\n");

        mysql_free_result(res);

	//printf("ended db_conf\n");

}
void db_update_pub_name(MYSQL *conn,char *username,char *pub_name) {
        //printf("start db_update_pub_name\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set conf_pubnm=\'%s\' where user_id=\'%s\'",pub_name,username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

}

void db_update_conf_pub_1(MYSQL *conn,char *username) {
        printf("start db_update_setpub\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set conf_pub=1 where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

	memset(query_buf,0x0,512);
        snprintf(query_buf,512,"update msghard_user set conf_pub_date=sysdate() where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }


}
void db_update_conf_pub_0(MYSQL *conn,char *username) {
        printf("start db_update_setpub\n");

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));

        snprintf(query_buf,512,"update msghard_user set conf_pub=0 where user_id=\'%s\'",username);

        if(mysql_real_query(conn,query_buf,strlen(query_buf))) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

}

void db_select_get_myclublist(MYSQL *conn,char *username,club_list *clublist_head,int *clublist_max_count) {
        club_list *p=NULL;
        printf("start db_select_get_myclublist\n");
        MYSQL_RES *res;
        MYSQL_ROW row;
	MYSQL_RES *sub_res;
	MYSQL_ROW sub_row;
	MYSQL_RES *sub2_res;
	MYSQL_ROW sub2_row;

        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));
        printf("check\n");

        snprintf(query_buf,512,"select club_name from msghard_club_user where user_id=\'%s\' order by reg_date desc",user_id);
        printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                error_handling("mysql error");
        }

        res=mysql_store_result(conn);
        printf("check1\n");
        p=clublist_head;


        while((row = mysql_fetch_row(res))) {
                printf("::getclublist while\n");
                club_list *node = (club_list*)malloc(sizeof(club_list));

                memset(node,0x0,sizeof(club_list));

                printf("user_id : %s \n",row[0]);
                memset(node->data.clubname,0x0,255);

		

		memset(query_buf,0x0,512);
	        snprintf(query_buf,512,"select owner_id,club_name,total_size from msghard_club where club_name=\'%s\' order by create_date desc",row[0]);

	        if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
	                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                	error_handling("mysql error");
      		}
		sub_res=mysql_store_result(conn);

		sub_row=mysql_fetch_row(sub_res);

		strncpy(node->data.ownername,sub_row[0],strlen(sub_row[0]));
                strncpy(node->data.clubname,sub_row[1],strlen(sub_row[1]));
                node->data.totalsize = atol(sub_row[2]);
                node->data.count = *clublist_max_count +1;
	
                (*clublist_max_count)++;

                memset(query_buf,0x0,512);
                snprintf(query_buf,512,"select count(*) from msghard_club_user where club_name=\'%s\'",node->data.clubname);

                if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                        printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn));
                        error_handling("mysql error");
                }
                sub2_res=mysql_store_result(conn);

                sub2_row=mysql_fetch_row(sub2_res);

		node->data.usercount=atoi(sub2_row[0]);





		printf("node->clubname : %s\n",node->data.clubname);
                printf("node->ownername : %s\n",node->data.ownername);
                printf("node->usercount : %d\n",node->data.usercount);
		printf("node->totalsize : %ld\n",node->data.totalsize);





                p->Next = node;


                printf("clublist_max_count : %d\n",*clublist_max_count);
                p=p->Next;
                printf("check\n");
		mysql_free_result(sub_res);
		mysql_free_result(sub2_res);
		memset(sub_row,0x0,sizeof(sub_row));
		memset(sub2_row,0x0,sizeof(sub2_row));


        }

        mysql_free_result(res);

        printf("ended db_get_myclublist\n");

}









void db_select_get_publist(MYSQL *conn,char *username,pub_list *publist_head,int *publist_max_count) {

	pub_list *p=NULL;
        printf("start db_select_get_publist\n");
        MYSQL_RES *res;
        MYSQL_ROW row;
        char query_buf[512];
        memset(query_buf,0x0,sizeof(query_buf));
        printf("check\n");

        snprintf(query_buf,512,"select user_id,conf_pubnm from msghard_user where conf_pub=1 order by conf_pub_date desc");
        printf("%s\n",query_buf);
        if(mysql_real_query(conn,query_buf,strlen(query_buf))!=0) {
                printf("error no : %d\n%s\n",mysql_errno(conn),mysql_error(conn)
);
                error_handling("mysql error");
        }

        res=mysql_store_result(conn);
        printf("check1\n");
	p=publist_head;
        while((row = mysql_fetch_row(res))) {
		printf("while\n");
		pub_list *node = (pub_list*)malloc(sizeof(pub_list));

		memset(node,0x0,sizeof(pub_list));
				
                printf("user_id : %s , subject : %s\n",row[0],row[1]);
		memset(node->data.username,0x0,256);

		strncpy(node->data.username , row[0] , strlen(row[0]));
		node->data.count = *publist_max_count +1;
		if(row[1] == NULL) {
			strcpy(node->data.subject,"");
		}
		else {
			strncpy(node->data.subject,row[1],strlen(row[1]));
		}
		p->Next = node;
		(*publist_max_count)++;



		printf("publist_max_count : %d\n",*publist_max_count);
		p=p->Next;
		printf("check\n");
        }

        mysql_free_result(res);

        printf("ended db_get_publist\n");

}
